# NotionAI-Chrome

NotionAI Chrome Extension is an open-source tool that provides a simple way to access the NotionAI API. It allows you to use NotionAI in any input field in Chrome with ease.

## Requirements

To use the extension, your Chrome cookie must send requests to Notion. Therefore, you must first log in to https://notion.so and ensure that you have access to NotionAI.

## Usage


I haven't uploaded it to the Chrome Store yet, so please download the repository and load it in developer mode.

1. Go to [release page](https://github.com/Vaayne/NotionAI/releases?q=chrome&expanded=true), download latest asset like `notionai-chrome-f5b65759f51486a9e280f4fd3622c9af7f466287.zip
`
2. unzip it and there will be a folder named `notionai-chrome`
3. Go to `chrome://extensions/` and enable Developer mode
4. Load the unpacked folder `notionai-chrome`
5. Refresh any web page and select any text in an input box, then right-click to use NotionAI!
